#[non_exhaustive]pub struct AzureDatabaseEncryption {
pub key_id: String,
/* private fields */
}๐Deprecated
Configuration related to application-layer secrets encryption.
Anthos clusters on Azure encrypts your Kubernetes data at rest in etcd using Azure Key Vault.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key_id: String๐Deprecated
Required. The ARM ID of the Azure Key Vault key to encrypt / decrypt data.
For example:
/subscriptions/<subscription-id>/resourceGroups/<resource-group-id>/providers/Microsoft.KeyVault/vaults/<key-vault-id>/keys/<key-name>
Encryption will always take the latest version of the key and hence
specific version is not supported.
Implementations