#[non_exhaustive]pub struct CreateAwsNodePoolRequest {
pub parent: String,
pub aws_node_pool: Option<AwsNodePool>,
pub aws_node_pool_id: String,
pub validate_only: bool,
/* private fields */
}Expand description
Response message for AwsClusters.CreateAwsNodePool method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The AwsCluster resource where this node pool will be created.
AwsCluster names are formatted as
projects/<project-id>/locations/<region>/awsClusters/<cluster-id>.
See Resource Names for more details on Google Cloud resource names.
aws_node_pool: Option<AwsNodePool>Required. The specification of the AwsNodePool to create.
aws_node_pool_id: StringRequired. A client provided ID the resource. Must be unique within the parent resource.
The provided ID will be part of the
AwsNodePool resource name
formatted as
projects/<project-id>/locations/<region>/awsClusters/<cluster-id>/awsNodePools/<node-pool-id>.
Valid characters are /[a-z][0-9]-/. Cannot be longer than 63 characters.
validate_only: boolIf set, only validate the request, but do not actually create the node pool.
Implementations
Sourceimpl CreateAwsNodePoolRequest
impl CreateAwsNodePoolRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_aws_node_pool<T>(self, v: T) -> Selfwhere
T: Into<AwsNodePool>,
pub fn set_aws_node_pool<T>(self, v: T) -> Selfwhere
T: Into<AwsNodePool>,
Sets the value of aws_node_pool.
Example
use google_cloud_gkemulticloud_v1::model::AwsNodePool;
let x = CreateAwsNodePoolRequest::new().set_aws_node_pool(AwsNodePool::default()/* use setters */);Sourcepub fn set_or_clear_aws_node_pool<T>(self, v: Option<T>) -> Selfwhere
T: Into<AwsNodePool>,
pub fn set_or_clear_aws_node_pool<T>(self, v: Option<T>) -> Selfwhere
T: Into<AwsNodePool>,
Sets or clears the value of aws_node_pool.
Example
use google_cloud_gkemulticloud_v1::model::AwsNodePool;
let x = CreateAwsNodePoolRequest::new().set_or_clear_aws_node_pool(Some(AwsNodePool::default()/* use setters */));
let x = CreateAwsNodePoolRequest::new().set_or_clear_aws_node_pool(None::<AwsNodePool>);Sourcepub fn set_aws_node_pool_id<T: Into<String>>(self, v: T) -> Self
pub fn set_aws_node_pool_id<T: Into<String>>(self, v: T) -> Self
Sets the value of aws_node_pool_id.
Example
let x = CreateAwsNodePoolRequest::new().set_aws_node_pool_id("example");Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = CreateAwsNodePoolRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for CreateAwsNodePoolRequest
impl Clone for CreateAwsNodePoolRequest
Sourcefn clone(&self) -> CreateAwsNodePoolRequest
fn clone(&self) -> CreateAwsNodePoolRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more