#[non_exhaustive]pub struct CreateAzureClientRequest {
pub parent: String,
pub azure_client: Option<AzureClient>,
pub azure_client_id: String,
pub validate_only: bool,
/* private fields */
}Expand description
Request message for AzureClusters.CreateAzureClient method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent location where this AzureClient resource will be created.
Location names are formatted as projects/<project-id>/locations/<region>.
See Resource Names for more details on Google Cloud resource names.
azure_client: Option<AzureClient>Required. The specification of the AzureClient to create.
azure_client_id: StringRequired. A client provided ID the resource. Must be unique within the parent resource.
The provided ID will be part of the
AzureClient resource name
formatted as
projects/<project-id>/locations/<region>/azureClients/<client-id>.
Valid characters are /[a-z][0-9]-/. Cannot be longer than 63 characters.
validate_only: boolIf set, only validate the request, but do not actually create the client.
Implementations
Sourceimpl CreateAzureClientRequest
impl CreateAzureClientRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_azure_client<T>(self, v: T) -> Selfwhere
T: Into<AzureClient>,
pub fn set_azure_client<T>(self, v: T) -> Selfwhere
T: Into<AzureClient>,
Sets the value of azure_client.
Example
use google_cloud_gkemulticloud_v1::model::AzureClient;
let x = CreateAzureClientRequest::new().set_azure_client(AzureClient::default()/* use setters */);Sourcepub fn set_or_clear_azure_client<T>(self, v: Option<T>) -> Selfwhere
T: Into<AzureClient>,
pub fn set_or_clear_azure_client<T>(self, v: Option<T>) -> Selfwhere
T: Into<AzureClient>,
Sets or clears the value of azure_client.
Example
use google_cloud_gkemulticloud_v1::model::AzureClient;
let x = CreateAzureClientRequest::new().set_or_clear_azure_client(Some(AzureClient::default()/* use setters */));
let x = CreateAzureClientRequest::new().set_or_clear_azure_client(None::<AzureClient>);Sourcepub fn set_azure_client_id<T: Into<String>>(self, v: T) -> Self
pub fn set_azure_client_id<T: Into<String>>(self, v: T) -> Self
Sets the value of azure_client_id.
Example
let x = CreateAzureClientRequest::new().set_azure_client_id("example");Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = CreateAzureClientRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for CreateAzureClientRequest
impl Clone for CreateAzureClientRequest
Sourcefn clone(&self) -> CreateAzureClientRequest
fn clone(&self) -> CreateAzureClientRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more