#[non_exhaustive]pub struct CreateAzureNodePoolRequest {
pub parent: String,
pub azure_node_pool: Option<AzureNodePool>,
pub azure_node_pool_id: String,
pub validate_only: bool,
/* private fields */
}Expand description
Response message for AzureClusters.CreateAzureNodePool method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The AzureCluster resource where this node pool will be created.
AzureCluster names are formatted as
projects/<project-id>/locations/<region>/azureClusters/<cluster-id>.
See Resource Names for more details on Google Cloud resource names.
azure_node_pool: Option<AzureNodePool>Required. The specification of the AzureNodePool to create.
azure_node_pool_id: StringRequired. A client provided ID the resource. Must be unique within the parent resource.
The provided ID will be part of the
AzureNodePool resource name
formatted as
projects/<project-id>/locations/<region>/azureClusters/<cluster-id>/azureNodePools/<node-pool-id>.
Valid characters are /[a-z][0-9]-/. Cannot be longer than 63 characters.
validate_only: boolIf set, only validate the request, but do not actually create the node pool.
Implementations
Sourceimpl CreateAzureNodePoolRequest
impl CreateAzureNodePoolRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_azure_node_pool<T>(self, v: T) -> Selfwhere
T: Into<AzureNodePool>,
pub fn set_azure_node_pool<T>(self, v: T) -> Selfwhere
T: Into<AzureNodePool>,
Sets the value of azure_node_pool.
Example
use google_cloud_gkemulticloud_v1::model::AzureNodePool;
let x = CreateAzureNodePoolRequest::new().set_azure_node_pool(AzureNodePool::default()/* use setters */);Sourcepub fn set_or_clear_azure_node_pool<T>(self, v: Option<T>) -> Selfwhere
T: Into<AzureNodePool>,
pub fn set_or_clear_azure_node_pool<T>(self, v: Option<T>) -> Selfwhere
T: Into<AzureNodePool>,
Sets or clears the value of azure_node_pool.
Example
use google_cloud_gkemulticloud_v1::model::AzureNodePool;
let x = CreateAzureNodePoolRequest::new().set_or_clear_azure_node_pool(Some(AzureNodePool::default()/* use setters */));
let x = CreateAzureNodePoolRequest::new().set_or_clear_azure_node_pool(None::<AzureNodePool>);Sourcepub fn set_azure_node_pool_id<T: Into<String>>(self, v: T) -> Self
pub fn set_azure_node_pool_id<T: Into<String>>(self, v: T) -> Self
Sets the value of azure_node_pool_id.
Example
let x = CreateAzureNodePoolRequest::new().set_azure_node_pool_id("example");Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = CreateAzureNodePoolRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for CreateAzureNodePoolRequest
impl Clone for CreateAzureNodePoolRequest
Sourcefn clone(&self) -> CreateAzureNodePoolRequest
fn clone(&self) -> CreateAzureNodePoolRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateAzureNodePoolRequest
impl Debug for CreateAzureNodePoolRequest
Sourceimpl Default for CreateAzureNodePoolRequest
impl Default for CreateAzureNodePoolRequest
Sourcefn default() -> CreateAzureNodePoolRequest
fn default() -> CreateAzureNodePoolRequest
Sourceimpl PartialEq for CreateAzureNodePoolRequest
impl PartialEq for CreateAzureNodePoolRequest
Sourcefn eq(&self, other: &CreateAzureNodePoolRequest) -> bool
fn eq(&self, other: &CreateAzureNodePoolRequest) -> bool
self and other values to be equal, and is used by ==.